package com.ipsplm.service.simulation.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ipsplm.dao.simulation.SimulationAnalysisMapper;
import com.ipsplm.entity.simulation.*;
import com.ipsplm.entity.simulation.vo.BufferVO;
import com.ipsplm.entity.simulation.vo.OeeVO;
import com.ipsplm.entity.simulation.vo.PlantEquipmentUtilizationVO;
import com.ipsplm.service.simulation.ISimulationAnalysisService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description 仿真分析实现类
 * @Author lulicheng
 * @Date 2024-07-31 10：20
 * @Version 1.0
 */
@Service
public class SimulationAnalysisServiceImpl implements ISimulationAnalysisService {
    @Autowired
    private SimulationAnalysisMapper simulationAnalysisMapper;

    /**
     * 获取厂房设备利用率信息
     *
     * @param flag
     * @return
     */
    @Override
    public List<OeeVO> getPlantEquipmentUtilization(Long flag) {
        List<PlantEquipmentUtilizationVO> plantEquipmentUtilization = simulationAnalysisMapper.getPlantEquipmentUtilization(flag);
        List<OeeVO> oeeVOList = beanToKeyValue(plantEquipmentUtilization);
        return oeeVOList;
    }

    /**
     * 获取工序列表
     *
     * @param tableCode
     * @return
     */
    @Override
    public List<String> getProcessList(String tableCode) {
        return simulationAnalysisMapper.getProcessList(tableCode);
    }

    /**
     * 获取缓存数量时间
     *
     * @param process
     * @return
     */
    @Override
    public Object getBufferNum(String process) {
        List<BufferVO> bufferNameList = simulationAnalysisMapper.getBufferName(process);
        String tableCode = bufferNameList.get(0).getTableCode();
        switch (tableCode) {
            case "buffernum_bxg": {
                List<BufferNumBxg> bufferNumBxgList = simulationAnalysisMapper.getBufferNumBxg(bufferNameList);
                return bufferNumBxgList;
            }
            case "buffernum_dj": {
                List<BufferNumDj> bufferNumDjList = simulationAnalysisMapper.getBufferNumDj(bufferNameList);
                return bufferNumDjList;
            }
            case "buffernum_xe": {
                List<BufferNumXe> bufferNumXeList = simulationAnalysisMapper.getBufferNumXe(bufferNameList);
                return bufferNumXeList;
            }
            case "buffernum_xy": {
                List<BufferNumXy> bufferNumXyList = simulationAnalysisMapper.getBufferNumXy(bufferNameList);
                return bufferNumXyList;
            }
            case "buffernum_ze": {
                List<BufferNumZe> bufferNumZeList = simulationAnalysisMapper.getBufferNumZe(bufferNameList);
                return bufferNumZeList;
            }
            case "buffernum_zy": {
                List<BufferNumZy> bufferNumZyList = simulationAnalysisMapper.getBufferNumZy(bufferNameList);
                return bufferNumZyList;
            }
            default:
                break;
        }
        return null;
    }

    /**
     * 获取OEE数据
     *
     * @param tableCode
     * @return
     */
    @Override
    public Object getOee(String tableCode) {
        switch (tableCode) {
            case "oee_bxg": {
                List<OeeBxg> oeeBxgList = simulationAnalysisMapper.getOeeBxg();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeBxgList);
                return oeeVOList;
            }
            case "oee_dj": {
                List<OeeDj> oeeDjList = simulationAnalysisMapper.getOeeDj();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeDjList);
                return oeeVOList;
            }
            case "oee_xe": {
                List<OeeXe> oeeXeList = simulationAnalysisMapper.getOeeXe();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeXeList);
                return oeeVOList;
            }
            case "oee_xy": {
                List<OeeXy> oeeXyList = simulationAnalysisMapper.getOeeXy();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeXyList);
                return oeeVOList;
            }
            case "oee_ze": {
                List<OeeZe> oeeZeList = simulationAnalysisMapper.getOeeZe();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeZeList);
                return oeeVOList;
            }
            case "oee_zy": {
                List<OeeZy> oeeZyList = simulationAnalysisMapper.getOeeZy();
                List<OeeVO> oeeVOList = beanToKeyValue(oeeZyList);
                return oeeVOList;
            }
            default:
                break;
        }
        return null;
    }

    /**
     * 获取对象的属性名和属性值并存入OeeVO对象的集合
     * @param oeeList
     * @return
     */
    public List<OeeVO> beanToKeyValue(List oeeList) {
        List<OeeVO> oeeVOList = new ArrayList<>();
        for (Object object : oeeList) {
            JSONObject jsonObject = (JSONObject) JSON.toJSON(object);
            Object status = jsonObject.get("status");
            for (Map.Entry<String, Object> entry : jsonObject.entrySet()) {
                OeeVO oeeVO = new OeeVO();
                Object value = entry.getValue();
                String key = entry.getKey();
                if ("flag".equals(key) || "id".equals(key) || "status".equals(key)) {
                    continue;
                }
                oeeVO.setName(key);
                oeeVO.setValue(value);
                oeeVO.setStatus(status);
                oeeVOList.add(oeeVO);
            }
        }
        return oeeVOList;
    }
}
